@@ -21,7 +21,7 @@ __author__ = 'Martin Dobias'
 __date__ = 'January 2007'
 __copyright__ = '(C) 2007, Martin Dobias'
 # This will get replaced with a git SHA1 when you do a git archive
-__revision__ = '26842169e9367434a27a70ab0df0bd4ba6ad1d7a'
+__revision__ = '0c5774c0685d4b6f3e92a086234455708d1cd427'
 
 from builtins import zip
 import os
@@ -59,7 +59,7 @@ def setupenv():
         for line in f:
             linedata = line.split("=")
             name = linedata[0]
-            data = linedata[1].rstrip()
+            data = linedata[1]
             os.environ[name] = data
 
 
