@@ -21,14 +21,14 @@ __author__ = 'Martin Dobias'
 __date__ = 'November 2009'
 __copyright__ = '(C) 2009, Martin Dobias'
 # This will get replaced with a git SHA1 when you do a git archive
-__revision__ = '93e761dd2396af21db9bb93e26d7cba680c906ca'
+__revision__ = '0c5774c0685d4b6f3e92a086234455708d1cd427'
 
 """
 QGIS utilities module
 
 """
 
-from qgis.PyQt.QtCore import QCoreApplication, QLocale, QThread
+from qgis.PyQt.QtCore import QCoreApplication, QLocale, QThread, qDebug
 from qgis.PyQt.QtWidgets import QPushButton, QApplication
 from qgis.core import Qgis, QgsMessageLog, qgsfunction, QgsMessageOutput
 from qgis.gui import QgsMessageBar
@@ -404,6 +404,9 @@ def _unloadPluginModules(packageName):
     mods = _plugin_modules[packageName]
 
     for mod in mods:
+        if not mod in sys.modules:
+            continue
+
         # if it looks like a Qt resource file, try to do a cleanup
         # otherwise we might experience a segfault next time the plugin is loaded
         # because Qt will try to access invalid plugin resource data
@@ -411,12 +414,23 @@ def _unloadPluginModules(packageName):
             if hasattr(sys.modules[mod], 'qCleanupResources'):
                 sys.modules[mod].qCleanupResources()
         except:
-            pass
+            # Print stack trace for debug
+            qDebug("qCleanupResources error:\n%s" % traceback.format_exc())
+
+        # try removing path
+        if hasattr(sys.modules[mod], '__path__'):
+            for path in sys.modules[mod].__path__:
+                try:
+                    sys.path.remove(path)
+                except ValueError:
+                    # Discard if path is not there
+                    pass
+
         # try to remove the module from python
         try:
             del sys.modules[mod]
         except:
-            pass
+            qDebug("Error when removing module:\n%s" % traceback.format_exc())
     # remove the plugin entry
     del _plugin_modules[packageName]
 
