@@ -23,7 +23,7 @@ __copyright__ = '(C) 2013, Alexander Bruy'
 
 # This will get replaced with a git SHA1 when you do a git archive
 
-__revision__ = '9b176802e5512bc310765d8ebe4e44b5f4663453'
+__revision__ = '0c5774c0685d4b6f3e92a086234455708d1cd427'
 
 import os
 
@@ -78,8 +78,8 @@ class rasterize_over(GdalAlgorithm):
         inLayer = QgsProcessingUtils.mapLayerFromString(self.getParameterValue(self.INPUT), context)
         inRasterLayer = QgsProcessingUtils.mapLayerFromString(self.getParameterValue(self.INPUT_RASTER), context)
 
-        ogrLayer = GdalUtils.ogrConnectionString(inLayer, context)
-        ogrRasterLayer = GdalUtils.ogrConnectionString(inRasterLayer, context)
+        ogrLayer = GdalUtils.ogrConnectionStringFromLayer(inLayer)
+        ogrRasterLayer = GdalUtils.ogrConnectionStringFromLayer(inRasterLayer)
 
         arguments = []
         arguments.append('-a')
