@@ -23,7 +23,7 @@ __copyright__ = '(C) 2012, Victor Olaya'
 
 # This will get replaced with a git SHA1 when you do a git archive
 
-__revision__ = '26842169e9367434a27a70ab0df0bd4ba6ad1d7a'
+__revision__ = '0c5774c0685d4b6f3e92a086234455708d1cd427'
 
 
 class AlgorithmDialogBase:
@@ -32,3 +32,9 @@ class AlgorithmDialogBase:
 
         def __init__(self, param, widget):
             (self.parameter, self.widget) = (param, widget)
+
+    class InvalidOutputExtension(Exception):
+
+        def __init__(self, widget, message):
+            self.widget = widget
+            self.message = message
