@@ -23,7 +23,7 @@ __copyright__ = '(C) 2014, Alexander Bruy'
 
 # This will get replaced with a git SHA1 when you do a git archive
 
-__revision__ = '26842169e9367434a27a70ab0df0bd4ba6ad1d7a'
+__revision__ = '0c5774c0685d4b6f3e92a086234455708d1cd427'
 
 import os
 import json
@@ -35,13 +35,23 @@ from qgis.PyQt.QtCore import QDir, QFileInfo
 from qgis.core import (Qgis,
                        QgsApplication,
                        QgsSettings,
-                       QgsProcessingParameterDefinition)
-from qgis.gui import QgsMessageBar
+                       QgsProcessingParameterMapLayer,
+                       QgsProcessingParameterRasterLayer,
+                       QgsProcessingParameterVectorLayer,
+                       QgsProcessingParameterMeshLayer,
+                       QgsProcessingParameterFile,
+                       QgsProcessingParameterDefinition,
+                       QgsProcessingModelAlgorithm)
+from qgis.gui import (QgsProcessingParameterWidgetContext,
+                      QgsProcessingContextGenerator)
+from qgis.utils import iface
 
-from processing.gui.wrappers import WidgetWrapperFactory
+from processing.gui.wrappers import WidgetWrapperFactory, WidgetWrapper
 from processing.gui.BatchOutputSelectionPanel import BatchOutputSelectionPanel
+from processing.gui.BatchInputSelectionPanel import BatchInputSelectionPanel
 
 from processing.tools import dataobjects
+from processing.tools.dataobjects import createContext
 
 pluginPath = os.path.split(os.path.dirname(__file__))[0]
 
@@ -86,6 +96,19 @@ class BatchPanel(BASE, WIDGET):
         self.tblParameters.horizontalHeader().setDefaultSectionSize(250)
         self.tblParameters.horizontalHeader().setMinimumSectionSize(150)
 
+        self.processing_context = createContext()
+
+        class ContextGenerator(QgsProcessingContextGenerator):
+
+            def __init__(self, context):
+                super().__init__()
+                self.processing_context = context
+
+            def processingContext(self):
+                return self.processing_context
+
+        self.context_generator = ContextGenerator(self.processing_context)
+
         self.initWidgets()
 
     def layerRegistryChanged(self):
@@ -99,10 +122,6 @@ class BatchPanel(BASE, WIDGET):
                 break
 
         # Determine column count
-        nOutputs = len(self.alg.destinationParameterDefinitions()) + 1
-        if nOutputs == 1:
-            nOutputs = 0
-
         self.tblParameters.setColumnCount(
             self.alg.countVisibleParameters())
 
@@ -123,11 +142,6 @@ class BatchPanel(BASE, WIDGET):
                     column, QTableWidgetItem(out.description()))
                 column += 1
 
-        # Last column for indicating if output will be added to canvas
-        if len(self.alg.destinationParameterDefinitions()) > 0:
-            self.tblParameters.setHorizontalHeaderItem(
-                column, QTableWidgetItem(self.tr('Load in QGIS')))
-
         # Add an empty row to begin
         self.addRow()
 
@@ -136,6 +150,7 @@ class BatchPanel(BASE, WIDGET):
         self.tblParameters.horizontalHeader().setStretchLastSection(True)
 
     def load(self):
+        context = dataobjects.createContext()
         settings = QgsSettings()
         last_path = settings.value("/Processing/LastBatchPath", QDir.homePath())
         filename, selected_filter = QFileDialog.getOpenFileName(self,
@@ -165,7 +180,7 @@ class BatchPanel(BASE, WIDGET):
                     if param.name() in params:
                         value = eval(params[param.name()])
                         wrapper = self.wrappers[row][column]
-                        wrapper.setValue(value)
+                        wrapper.setParameterValue(value, context)
                     column += 1
 
                 for out in self.alg.destinationParameterDefinitions():
@@ -196,12 +211,24 @@ class BatchPanel(BASE, WIDGET):
                 if param.isDestination():
                     continue
                 wrapper = self.wrappers[row][col]
-                if not param.checkValueIsAcceptable(wrapper.value(), context):
+
+                # For compatibility with 3.x API, we need to check whether the wrapper is
+                # the deprecated WidgetWrapper class. If not, it's the newer
+                # QgsAbstractProcessingParameterWidgetWrapper class
+                # TODO QGIS 4.0 - remove
+                if issubclass(wrapper.__class__, WidgetWrapper):
+                    widget = wrapper.widget
+                else:
+                    widget = wrapper.wrappedWidget()
+
+                value = wrapper.parameterValue()
+
+                if not param.checkValueIsAcceptable(value, context):
                     self.parent.messageBar().pushMessage("", self.tr('Wrong or missing parameter value: {0} (row {1})').format(
                         param.description(), row + 1),
                         level=Qgis.Warning, duration=5)
                     return
-                algParams[param.name()] = param.valueAsPythonString(wrapper.value(), context)
+                algParams[param.name()] = param.valueAsPythonString(value, context)
                 col += 1
             for out in alg.destinationParameterDefinitions():
                 if out.flags() & QgsProcessingParameterDefinition.FlagHidden:
@@ -232,14 +259,35 @@ class BatchPanel(BASE, WIDGET):
             with open(filename, 'w') as f:
                 json.dump(toSave, f)
 
-    def setCellWrapper(self, row, column, wrapper):
+    def setCellWrapper(self, row, column, wrapper, context):
         self.wrappers[row][column] = wrapper
-        self.tblParameters.setCellWidget(row, column, wrapper.widget)
+
+        widget_context = QgsProcessingParameterWidgetContext()
+        if iface is not None:
+            widget_context.setMapCanvas(iface.mapCanvas())
+        if isinstance(self.alg, QgsProcessingModelAlgorithm):
+            widget_context.setModel(self.alg)
+        wrapper.setWidgetContext(widget_context)
+        wrapper.registerProcessingContextGenerator(self.context_generator)
+
+        # For compatibility with 3.x API, we need to check whether the wrapper is
+        # the deprecated WidgetWrapper class. If not, it's the newer
+        # QgsAbstractProcessingParameterWidgetWrapper class
+        # TODO QGIS 4.0 - remove
+        is_cpp_wrapper = not issubclass(wrapper.__class__, WidgetWrapper)
+        if is_cpp_wrapper:
+            widget = wrapper.createWrappedWidget(context)
+        else:
+            widget = wrapper.widget
+
+        self.tblParameters.setCellWidget(row, column, widget)
 
     def addRow(self):
         self.wrappers.append([None] * self.tblParameters.columnCount())
         self.tblParameters.setRowCount(self.tblParameters.rowCount() + 1)
 
+        context = dataobjects.createContext()
+
         wrappers = {}
         row = self.tblParameters.rowCount() - 1
         column = 0
@@ -247,9 +295,17 @@ class BatchPanel(BASE, WIDGET):
             if param.flags() & QgsProcessingParameterDefinition.FlagHidden or param.isDestination():
                 continue
 
-            wrapper = WidgetWrapperFactory.create_wrapper(param, self.parent, row, column)
-            wrappers[param.name()] = wrapper
-            self.setCellWrapper(row, column, wrapper)
+            if isinstance(param, (QgsProcessingParameterMapLayer, QgsProcessingParameterRasterLayer,
+                                  QgsProcessingParameterVectorLayer, QgsProcessingParameterMeshLayer,
+                                  QgsProcessingParameterFile)):
+                self.tblParameters.setCellWidget(
+                    row, column, BatchInputSelectionPanel(
+                        param, row, column, self.parent))
+            else:
+                wrapper = WidgetWrapperFactory.create_wrapper(param, self.parent, row, column)
+                wrappers[param.name()] = wrapper
+                self.setCellWrapper(row, column, wrapper, context)
+
             column += 1
 
         for out in self.alg.destinationParameterDefinitions():
@@ -277,13 +333,15 @@ class BatchPanel(BASE, WIDGET):
             self.tblParameters.setRowCount(self.tblParameters.rowCount() - 1)
 
     def fillParameterValues(self, column):
+        context = dataobjects.createContext()
+
         wrapper = self.wrappers[0][column]
         if wrapper is None:
             # e.g. double clicking on a destination header
             return
 
         for row in range(1, self.tblParameters.rowCount()):
-            self.wrappers[row][column].setValue(wrapper.value())
+            self.wrappers[row][column].setParameterValue(wrapper.parameterValue(), context)
 
     def toggleAdvancedMode(self, checked):
         for column, param in enumerate(self.alg.parameterDefinitions()):
