@@ -24,7 +24,7 @@ __copyright__ = '(C) 2017, Nyall Dawson'
 
 # This will get replaced with a git SHA1 when you do a git archive
 
-__revision__ = '93e761dd2396af21db9bb93e26d7cba680c906ca'
+__revision__ = '0c5774c0685d4b6f3e92a086234455708d1cd427'
 
 from qgis.core import (QgsProcessing,
                        QgsProviderRegistry,
@@ -85,7 +85,7 @@ def getFileFilter(param):
         return param.fileFilter() + ';;' + tr('All files (*.*)')
     elif param.type() == 'mesh':
         return tr('All files (*.*)')
-    if param.defaultFileExtension():
+    if hasattr(param, 'defaultFileExtension') and param.defaultFileExtension():
         return tr('Default extension') + ' (*.' + param.defaultFileExtension() + ')'
     else:
         return ''
