@@ -23,7 +23,7 @@ __copyright__ = '(C) 2012, Victor Olaya'
 
 # This will get replaced with a git SHA1 when you do a git archive
 
-__revision__ = '58734527abdbaab95719a48a4a64ea05abd70b44'
+__revision__ = '0c5774c0685d4b6f3e92a086234455708d1cd427'
 
 import math
 
@@ -96,7 +96,8 @@ class ModelerParameterDefinitionDialog(QDialog):
         super(ModelerParameterDefinitionDialog, self).closeEvent(event)
 
     def setupUi(self):
-        self.setWindowTitle(self.tr('Parameter Definition'))
+        type_metadata = QgsApplication.processingRegistry().parameterType(self.param.type() if self.param else self.paramType)
+        self.setWindowTitle(self.tr('{} Parameter Definition').format(type_metadata.name()))
         self.setMinimumWidth(300)
 
         self.verticalLayout = QVBoxLayout(self)
@@ -228,6 +229,14 @@ class ModelerParameterDefinitionDialog(QDialog):
                                 self.parentCombo.setCurrentIndex(idx)
                         idx += 1
                 self.verticalLayout.addWidget(self.parentCombo)
+            else:
+                self.verticalLayout.addWidget(QLabel(self.tr('Number type')))
+                self.type_combo = QComboBox()
+                self.type_combo.addItem(self.tr('Float'), QgsProcessingParameterNumber.Double)
+                self.type_combo.addItem(self.tr('Integer'), QgsProcessingParameterNumber.Integer)
+                if self.param:
+                    self.type_combo.setCurrentIndex(self.type_combo.findData(self.param.dataType()))
+                self.verticalLayout.addWidget(self.type_combo)
 
             self.verticalLayout.addWidget(QLabel(self.tr('Min value')))
             self.minTextBox = QLineEdit()
@@ -244,7 +253,7 @@ class ModelerParameterDefinitionDialog(QDialog):
             if self.param is not None:
                 default = self.param.defaultValue()
                 if self.param.dataType() == QgsProcessingParameterNumber.Integer:
-                    default = int(math.floor(default))
+                    default = int(math.floor(float(default)))
                 if default:
                     self.defaultTextBox.setText(str(default))
             self.verticalLayout.addWidget(self.defaultTextBox)
@@ -444,7 +453,9 @@ class ModelerParameterDefinitionDialog(QDialog):
                 self.param.setParentParameterName(parent)
         elif (self.paramType == parameters.PARAMETER_NUMBER or
               isinstance(self.param, QgsProcessingParameterNumber)):
-            self.param = QgsProcessingParameterNumber(name, description, QgsProcessingParameterNumber.Double,
+
+            type = self.type_combo.currentData()
+            self.param = QgsProcessingParameterNumber(name, description, type,
                                                       self.defaultTextBox.text())
             try:
                 vmin = self.minTextBox.text().strip()
