@@ -24,7 +24,7 @@ __copyright__ = '(C) 2012, Victor Olaya'
 
 # This will get replaced with a git SHA1 when you do a git archive
 
-__revision__ = '9b176802e5512bc310765d8ebe4e44b5f4663453'
+__revision__ = '0c5774c0685d4b6f3e92a086234455708d1cd427'
 
 from qgis.PyQt.QtCore import QPointF, Qt
 from qgis.PyQt.QtWidgets import QGraphicsItem, QGraphicsScene
@@ -47,16 +47,16 @@ class ModelerScene(QGraphicsScene):
         self.dialog = dialog
 
     def getParameterPositions(self):
-        return {key: item.pos() for key, item in list(self.paramItems.items())}
+        return {key: item.pos() for key, item in self.paramItems.items()}
 
     def getAlgorithmPositions(self):
-        return {key: item.pos() for key, item in list(self.algItems.items())}
+        return {key: item.pos() for key, item in self.algItems.items()}
 
     def getOutputPositions(self):
         pos = {}
-        for algName, outputs in list(self.outputItems.items()):
+        for algName, outputs in self.outputItems.items():
             outputPos = {}
-            for (key, value) in list(outputs.items()):
+            for key, value in outputs.items():
                 if value is not None:
                     outputPos[key] = value.pos()
                 else:
@@ -103,8 +103,12 @@ class ModelerScene(QGraphicsScene):
         for input_name in list(model.parameterComponents().keys()):
             idx = 0
             parameter_def = model.parameterDefinition(input_name)
+            parent_name = None
             if hasattr(parameter_def, 'parentLayerParameterName') and parameter_def.parentLayerParameterName():
                 parent_name = parameter_def.parentLayerParameterName()
+            elif hasattr(parameter_def, 'parentParameterName') and parameter_def.parentParameterName():
+                parent_name = parameter_def.parentParameterName()
+            if parent_name:
                 if input_name in self.paramItems and parent_name in self.paramItems:
                     input_item = self.paramItems[input_name]
                     parent_item = self.paramItems[parent_name]
